FigTreeTextTheme extension

FigTreeTextTheme is an extension on BuildContext !!! Keeping null checks for all used text theme properties of flutter !!! As we have given a fixated text style which will never be null in app when using text theme extensions.

on

Properties

body1 TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Body 1 is Flutter Body Large with 16px size and 145% height
no setter
body2 TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Body 2 is Flutter Body Medium with 14px size and 150% height
no setter
body3 TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Body 3 is Flutter Body Small with 13px size and 150% height
no setter
buttonMedium TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Button Medium is Text Style with 14px size and 160% height
no setter
buttonSmall TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Button Small is Text Style with 12px size and 150% height
no setter
caption TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Caption is Text Style with 12px size and 150% height
no setter
display1 TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Display 1 is Flutter Display Large with 118px size and 125% height
no setter
display2 TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Display 2 is Flutter Display Medium with 84px size and 125% height
no setter
display3 TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Display 3 is Flutter Display Small with 64px size and 130% height
no setter
headline1 TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Headline 1 is Flutter Headline Large with 50px size and 130% height
no setter
headline2 TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Headline 2 is Flutter Headline Medium with 32px size and 130% height
no setter
headline3 TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Headline 3 is Flutter Headline Small with 28px size and 130% height
no setter
labelExtraSmall TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Label Extra Small is Text Style with 12px size and 160% height and 10% letter spacing
no setter
labelSmall TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Label Small is Flutter Label Small with 14px size and 150% height and 10% letter spacing
no setter
overline TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Overline is Text Style with 11px size and 160% height
no setter
title1 TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Title 1 is Flutter Title Large with 24px size and 130% height
no setter
title2 TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Title 2 is Flutter Title Medium with 20px size and 140% height
no setter
title3 TextStyle

Available on BuildContext, provided by the FigTreeTextTheme extension

Title 3 is Flutter Title Small with 18px size and 140% height
no setter
tt TextTheme

Available on BuildContext, provided by the FigTreeTextTheme extension

no setter