CustomInkWell class
Inheritance
Mixed-in types
Constructors
CustomInkWell ({Key ? key , required BuildContext context , required String trackLabel , required String semanticsLabel , Widget ? child , GestureTapCallback ? onTap , GestureTapCallback ? onDoubleTap , GestureLongPressCallback ? onLongPress , GestureTapDownCallback ? onTapDown , GestureTapUpCallback ? onTapUp , GestureTapCallback ? onTapCancel , ValueChanged <bool > ? onHighlightChanged , ValueChanged <bool > ? onHover , MouseCursor ? mouseCursor , Color ? focusColor , Color ? hoverColor , Color ? highlightColor , WidgetStateProperty <Color ? > ? overlayColor , Color ? splashColor , InteractiveInkFeatureFactory ? splashFactory , double ? radius , BorderRadius ? borderRadius , ShapeBorder ? customBorder , bool excludeFromSemantics = false , FocusNode ? focusNode , bool canRequestFocus = true , ValueChanged <bool > ? onFocusChange , bool autofocus = false , MaterialStatesController ? statesController , bool enableFeedback = true , Map <String , dynamic > ? trackProperties , bool enabled = true , bool enableTracking = true })
const
Properties
autofocus
→ bool
True if this widget will be selected as the initial focus when no other
node in its scope is currently focused.
final inherited
borderRadius
→ BorderRadius ?
The border radius of the containing rectangle. This is effective only if
highlightShape is BoxShape.rectangle .
final inherited
canRequestFocus
→ bool
If true, this widget may request the primary focus.
final inherited
child
→ Widget ?
The widget below this widget in the tree.
no setter override
containedInkWell
→ bool
Whether this ink response should be clipped its bounds.
final inherited
context
→ BuildContext
final
customBorder
→ ShapeBorder ?
The custom clip border.
final inherited
enabled
→ bool
final
enableFeedback
→ bool
Whether detected gestures should provide acoustic and/or haptic feedback.
final inherited
enableTracking
→ bool
final
excludeFromSemantics
→ bool
Whether to exclude the gestures introduced by this widget from the
semantics tree.
final inherited
focusColor
→ Color ?
The color of the ink response when the parent widget is focused. If this
property is null then the focus color of the theme,
ThemeData.focusColor , will be used.
final inherited
focusNode
→ FocusNode ?
An optional focus node to use as the focus node for this widget.
final inherited
hashCode
→ int
The hash code for this object.
no setter inherited
highlightColor
→ Color ?
The highlight color of the ink response when pressed. If this property is
null then the highlight color of the theme, ThemeData.highlightColor ,
will be used.
final inherited
highlightShape
→ BoxShape
The shape (e.g., circle, rectangle) to use for the highlight drawn around
this part of the material when pressed, hovered over, or focused.
final inherited
hoverColor
→ Color ?
The color of the ink response when a pointer is hovering over it. If this
property is null then the hover color of the theme,
ThemeData.hoverColor , will be used.
final inherited
hoverDuration
→ Duration ?
The duration of the animation that animates the hover effect.
final inherited
key
→ Key ?
Controls how one widget replaces another widget in the tree.
final inherited
mouseCursor
→ MouseCursor ?
The cursor for a mouse pointer when it enters or is hovering over the
widget.
final inherited
onDoubleTap
→ GestureTapCallback ?
Called when the user double taps this part of the material.
final inherited
onFocusChange
→ ValueChanged <bool > ?
Handler called when the focus changes.
final inherited
onHighlightChanged
→ ValueChanged <bool > ?
Called when this part of the material either becomes highlighted or stops
being highlighted.
final inherited
onHover
→ ValueChanged <bool > ?
Called when a pointer enters or exits the ink response area.
final inherited
onLongPress
→ GestureLongPressCallback ?
Called when the user long-presses on this part of the material.
final inherited
onLongPressUp
→ GestureLongPressUpCallback ?
Called when the user lifts their finger after a long press on the button.
final inherited
onSecondaryTap
→ GestureTapCallback ?
Called when the user taps this part of the material with a secondary button.
final inherited
onSecondaryTapCancel
→ GestureTapCallback ?
Called when the user cancels a secondary button tap that was started on
this part of the material.
final inherited
onSecondaryTapDown
→ GestureTapDownCallback ?
Called when the user taps down on this part of the material with a
secondary button.
final inherited
onSecondaryTapUp
→ GestureTapUpCallback ?
Called when the user releases a secondary button tap that was started on
this part of the material. onSecondaryTap is called immediately after.
final inherited
onTap
→ VoidCallback ?
Called when the user taps this part of the material.
no setter override
onTapCancel
→ GestureTapCallback ?
Called when the user cancels a tap that was started on this part of the
material.
final inherited
onTapDown
→ GestureTapDownCallback ?
Called when the user taps down this part of the material.
final inherited
onTapUp
→ GestureTapUpCallback ?
Called when the user releases a tap that was started on this part of the
material. onTap is called immediately after.
final inherited
overlayColor
→ WidgetStateProperty <Color ? > ?
Defines the ink response focus, hover, and splash colors.
final inherited
radius
→ double ?
The radius of the ink splash.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
semanticsLabel
→ String
final
splashColor
→ Color ?
The splash color of the ink response. If this property is null then the
splash color of the theme, ThemeData.splashColor , will be used.
final inherited
splashFactory
→ InteractiveInkFeatureFactory ?
Defines the appearance of the splash.
final inherited
statesController
→ MaterialStatesController ?
Represents the interactive "state" of this widget in terms of
a set of WidgetState s, like WidgetState.pressed and
WidgetState.focused .
final inherited
trackLabel
→ String
trackLabel helps to identify the button, on analytics
final
trackProperties
→ Map <String , dynamic > ?
final
Methods
build (BuildContext context )
→ Widget
Describes the part of the user interface represented by this widget.
inherited
createElement ()
→ StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugCheckContext (BuildContext context )
→ bool
Asserts that the given context satisfies the prerequisites for
this class.
inherited
debugDescribeChildren ()
→ List <DiagnosticsNode >
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
debugFillProperties (DiagnosticPropertiesBuilder properties )
→ void
Add additional properties associated with the node.
inherited
getRectCallback (RenderBox referenceBox )
→ RectCallback ?
The rectangle to use for the highlight effect and for clipping
the splash effects if containedInkWell is true.
inherited
logClickEvent (BuildContext context , String trackLabel , {Map <String , dynamic > ? trackProperties , required bool enableTracking })
→ void
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode ({String ? name , DiagnosticsTreeStyle ? style })
→ DiagnosticsNode
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep .
inherited
toString ({DiagnosticLevel minLevel = DiagnosticLevel.info })
→ String
A string representation of this object.
inherited
toStringDeep ({String prefixLineOne = '' , String ? prefixOtherLines , DiagnosticLevel minLevel = DiagnosticLevel.debug , int wrapWidth = 65 })
→ String
Returns a string representation of this node and its descendants.
inherited
toStringShallow ({String joiner = ', ' , DiagnosticLevel minLevel = DiagnosticLevel.debug })
→ String
Returns a one-line detailed description of the object.
inherited
toStringShort ()
→ String
A short, textual description of this widget.
inherited
ledger_design_system 1.0.7