LedgerButton class

Inheritance
Mixed-in types

Constructors

LedgerButton.ghost({Key? key, required String trackLabel, bool enableTracking = true, String? label, String? prefixIconPath, String? suffixIconPath, String? package, VoidCallback? onPressed, LedgerButtonSize size = LedgerButtonSize.xtraLarge, bool loading = false, bool enable = true, Map<String, dynamic>? trackProperties, String? semanticsLabel, Color? foregroundColor, Color? backgroundColor, Widget? labelWidget, TextStyle? textStyle, bool shrink = false, bool? enableFeedback})
const
LedgerButton.primary1({Key? key, required String trackLabel, bool enableTracking = true, String? label, String? prefixIconPath, String? suffixIconPath, String? package, VoidCallback? onPressed, LedgerButtonSize size = LedgerButtonSize.xtraLarge, bool loading = false, bool enable = true, Map<String, dynamic>? trackProperties, String? semanticsLabel, Color? foregroundColor, Color? backgroundColor, Widget? labelWidget, TextStyle? textStyle, bool shrink = false, bool? enableFeedback})
const
LedgerButton.primary2({Key? key, required String trackLabel, bool enableTracking = true, String? label, String? prefixIconPath, String? suffixIconPath, String? package, VoidCallback? onPressed, LedgerButtonSize size = LedgerButtonSize.xtraLarge, bool loading = false, bool enable = true, Map<String, dynamic>? trackProperties, String? semanticsLabel, Color? foregroundColor, Color? backgroundColor, Widget? labelWidget, TextStyle? textStyle, bool shrink = false, bool? enableFeedback})
const
LedgerButton.secondary({Key? key, required String trackLabel, bool enableTracking = true, String? label, String? prefixIconPath, String? suffixIconPath, String? package, VoidCallback? onPressed, LedgerButtonSize size = LedgerButtonSize.xtraLarge, bool loading = false, bool enable = true, Map<String, dynamic>? trackProperties, String? semanticsLabel, Color? foregroundColor, Color? backgroundColor, Widget? labelWidget, TextStyle? textStyle, bool shrink = false, bool? enableFeedback})
const
LedgerButton.tertiary1({Key? key, required String trackLabel, bool enableTracking = true, String? label, String? prefixIconPath, String? suffixIconPath, String? package, VoidCallback? onPressed, LedgerButtonSize size = LedgerButtonSize.xtraLarge, bool loading = false, bool enable = true, Map<String, dynamic>? trackProperties, String? semanticsLabel, Color? foregroundColor, Color? backgroundColor, Widget? labelWidget, TextStyle? textStyle, bool shrink = false, bool? enableFeedback})
const
LedgerButton.tertiary2({Key? key, required String trackLabel, bool enableTracking = true, String? label, String? prefixIconPath, String? suffixIconPath, String? package, VoidCallback? onPressed, LedgerButtonSize size = LedgerButtonSize.xtraLarge, bool loading = false, bool enable = true, Map<String, dynamic>? trackProperties, String? semanticsLabel, Color? foregroundColor, Color? backgroundColor, Widget? labelWidget, TextStyle? textStyle, bool shrink = false, bool? enableFeedback})
const

Properties

backgroundColor Color?
final
borderRadius BorderRadius
no setter
enable bool
final
enableFeedback bool?
final
enableTracking bool
final
foregroundColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
labelWidget Widget?
final
loading bool
final
mainAxisSize MainAxisSize
no setter
onPressed VoidCallback?
final
package String?
final
prefixIconPath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel String?
final
shrink bool
final
size LedgerButtonSize
final
spacing Widget
no setter
suffixIconPath String?
final
textStyle TextStyle?
final
trackLabel String
trackLabel helps to identify the button, on analytics
final
trackProperties Map<String, dynamic>?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
logClickEvent(BuildContext context, String trackLabel, {Map<String, dynamic>? trackProperties, required bool enableTracking}) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onClick(BuildContext context) VoidCallback?
style(BuildContext context) TextStyle
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited