LedgerCheckboxWithLabel class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- LedgerCheckboxWithLabel
Constructors
-
LedgerCheckboxWithLabel({Key? key, required bool checked, required String trackLabel, required String semanticsLabel, double size = 20.0, Color? activeColor, Color? borderColor, Color? checkColor, ValueChanged<
bool> ? onChanged, String label = '', String? subtitle, TextStyle? labelStyle, TextStyle? subtitleStyle, bool? enabled}) -
const
-
LedgerCheckboxWithLabel.circular({Key? key, required bool checked, required String trackLabel, required String semanticsLabel, double size = 20.0, Color? activeColor, Color? borderColor, Color? checkColor, ValueChanged<
bool> ? onChanged, String label = '', String? subtitle, TextStyle? labelStyle, TextStyle? subtitleStyle, bool? enabled}) -
const
Properties
- activeColor → Color?
-
final
- borderColor → Color?
-
final
- checkColor → Color?
-
final
- checked → bool
-
final
- enabled → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String
-
final
- labelStyle → TextStyle?
-
final
-
onChanged
→ ValueChanged<
bool> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticsLabel → String
-
final
- size → double
-
final
- subtitle → String?
-
final
- subtitleStyle → TextStyle?
-
final
- trackLabel → String
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< LedgerCheckboxWithLabel> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited