LedgerCustomDatePicker class

Inheritance

Constructors

LedgerCustomDatePicker({Key? key, DateTime? selectedDate, DateTime? initialDate, DateTime? minDate, DateTime? maxDate, Widget? placeHolder, String placeholderText = '', ValueChanged<DateTime>? onSelected, String dateDisplayFormat = 'dd-MM-yyyy', bool readOnly = false, bool showIcon = true, required String label, String? validator(String?)?, AutovalidateMode? autovalidateMode})
const

Properties

autovalidateMode AutovalidateMode?
final
dateDisplayFormat String
final
hashCode int
The hash code for this object.
no setterinherited
initialDate DateTime?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
final
maxDate DateTime?
final
minDate DateTime?
final
onSelected ValueChanged<DateTime>?
final
placeHolder Widget?
final
placeholderText String
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedDate DateTime?
final
showIcon bool
final
validator String? Function(String?)?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<LedgerCustomDatePicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited