LedgerIconButtonSize enum
Values
- small → const LedgerIconButtonSize
-
16.sp
const LedgerIconButtonSize(16) - medium → const LedgerIconButtonSize
-
20.sp
const LedgerIconButtonSize(20) - large → const LedgerIconButtonSize
-
24.sp
const LedgerIconButtonSize(24) - extraLarge → const LedgerIconButtonSize
-
32.sp
const LedgerIconButtonSize(32) - huge → const LedgerIconButtonSize
-
48.sp
const LedgerIconButtonSize(48)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
final
- value → double
-
Give value in sp
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
LedgerIconButtonSize> - A constant List of the values in this enum, in order of their declaration.