trailingAssetPath property

String? trailingAssetPath
final

trailingAssetPath sets the icon data for trailing cta, when not null

onTrailingPressed and trailingAssetPath should be not null for trailing icon to render

Implementation

final String? trailingAssetPath;