LedgerTextField class

Inheritance

Constructors

LedgerTextField({Key? key, EdgeInsets? margin, Widget? suffix, Widget? prefix, String? label, String? hintText, ValueChanged<String>? onClear, bool showLabel = true, bool showClear = true, TextEditingController? controller, ValueChanged<String>? onChanged, String? initialValue, FocusNode? focusNode, InputDecoration? decoration, TextInputType? keyboardType, TextCapitalization textCapitalization = TextCapitalization.none, TextInputAction? textInputAction, TextStyle? style, TextStyle? hintStyle, TextStyle? labelStyle, StrutStyle? strutStyle, TextDirection? textDirection, TextAlign textAlign = TextAlign.start, TextAlignVertical? textAlignVertical, bool autofocus = false, bool readOnly = false, String obscuringCharacter = '•', bool obscureText = false, bool autocorrect = false, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool enableSuggestions = false, MaxLengthEnforcement? maxLengthEnforcement, int maxLines = 1, int? minLines, bool expands = false, int? maxLength, GestureTapCallback? onTap, TapRegionCallback? onTapOutside, VoidCallback? onEditingComplete, ValueChanged<String>? onFieldSubmitted, ValueChanged<String?>? onSaved, String? validator(String? value)?, List<TextInputFormatter>? inputFormatters, bool? enabled, double cursorWidth = 2.0, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, bool? filled, Color? fillColor, Brightness? keyboardAppearance, EdgeInsets scrollPadding = const EdgeInsets.all(20), bool? enableInteractiveSelection, TextSelectionControls? selectionControls, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, AutovalidateMode? autovalidateMode, ScrollController? scrollController, String? restorationId, bool enableIMEPersonalizedLearning = false, MouseCursor? mouseCursor, EditableTextContextMenuBuilder? contextMenuBuilder, SpellCheckConfiguration? spellCheckConfiguration, TextMagnifierConfiguration? magnifierConfiguration, bool? showCursor})
const

Properties

autocorrect bool
final
autofillHints Iterable<String>?
final
autofocus bool
final
autovalidateMode AutovalidateMode?
final
buildCounter InputCounterWidgetBuilder?
final
contextMenuBuilder EditableTextContextMenuBuilder?
final
controller TextEditingController?
final
cursorColor Color?
final
cursorHeight double?
final
cursorRadius Radius?
final
cursorWidth double
final
decoration InputDecoration?
final
enabled bool?
final
enableIMEPersonalizedLearning bool
final
enableInteractiveSelection bool?
final
enableSuggestions bool
final
expands bool
final
fillColor Color?
final
filled bool?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
hintStyle TextStyle?
final
hintText String?
final
initialValue String?
final
inputFormatters List<TextInputFormatter>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance Brightness?
final
keyboardType TextInputType?
final
label String?
final
labelStyle TextStyle?
final
magnifierConfiguration TextMagnifierConfiguration?
final
margin EdgeInsets?
final
maxLength int?
final
maxLengthEnforcement MaxLengthEnforcement?
final
maxLines int
final
minLines int?
final
mouseCursor MouseCursor?
final
obscureText bool
final
obscuringCharacter String
final
onChanged ValueChanged<String>?
final
onClear ValueChanged<String>?
final
onEditingComplete VoidCallback?
final
onFieldSubmitted ValueChanged<String>?
final
onSaved ValueChanged<String?>?
final
onTap GestureTapCallback?
final
onTapOutside TapRegionCallback?
final
prefix Widget?
final
readOnly bool
final
restorationId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollController ScrollController?
final
scrollPadding EdgeInsets
final
scrollPhysics ScrollPhysics?
final
selectionControls TextSelectionControls?
final
showClear bool
final
showCursor bool?
final
showLabel bool
final
smartDashesType SmartDashesType?
final
smartQuotesType SmartQuotesType?
final
spellCheckConfiguration SpellCheckConfiguration?
final
strutStyle StrutStyle?
final
style TextStyle?
final
suffix Widget?
final
textAlign TextAlign
final
textAlignVertical TextAlignVertical?
final
textCapitalization TextCapitalization
final
textDirection TextDirection?
final
textInputAction TextInputAction?
final
validator String? Function(String? value)?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<LedgerTextField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited