RadiusSpacing enum
Values
- rdsnull → const RadiusSpacing
-
0 radius spacing
const RadiusSpacing(0) - rdsxs → const RadiusSpacing
-
4 radius spacing
const RadiusSpacing(4) - rdss → const RadiusSpacing
-
8 radius spacing
const RadiusSpacing(8) - rdsm → const RadiusSpacing
-
10 radius spacing
const RadiusSpacing(10) - rdsl → const RadiusSpacing
-
12 radius spacing
const RadiusSpacing(12) - rdsxl → const RadiusSpacing
-
16 radius spacing
const RadiusSpacing(16) - rds2xl → const RadiusSpacing
-
20 radius spacing
const RadiusSpacing(20) - rdscircular → const RadiusSpacing
-
100 radius spacing
const RadiusSpacing(100)
Properties
- all → BorderRadius
-
no setter
- bottomCorners → BorderRadius
-
no setter
- bottomLeft → BorderRadius
-
no setter
- bottomRight → BorderRadius
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- leftCorners → BorderRadius
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - r → Radius
-
no setter
- rightCorners → BorderRadius
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topCorners → BorderRadius
-
no setter
- topLeft → BorderRadius
-
no setter
- topRight → BorderRadius
-
no setter
- value → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator *(
double other) → double -
operator +(
double other) → double -
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RadiusSpacing> - A constant List of the values in this enum, in order of their declaration.