LedgerStatusCard class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- LedgerStatusCard
Constructors
- LedgerStatusCard.info({Key? key, String? title, String? description, Widget? prefixIcon, Widget? body, String? ctaText, VoidCallback? onTapCta, void onClose(BuildContext context)?, Key? ctaButtonKey, Color? bgColor, Color? textColor, TextStyle? titleStyle, TextStyle? descriptionStyle, String? trailingAssetPath, void onTrailingPressed(BuildContext context)?})
-
const
- LedgerStatusCard.pending({Key? key, String? description, String? title, Widget? prefixIcon, Widget? body, String? ctaText, VoidCallback? onTapCta, void onClose(BuildContext context)?, Key? ctaButtonKey, Color? bgColor, Color? textColor, TextStyle? titleStyle, TextStyle? descriptionStyle, String? trailingAssetPath, void onTrailingPressed(BuildContext context)?})
-
const
- LedgerStatusCard.success({Key? key, String? title, String? description, Widget? prefixIcon, Widget? body, void onClose(BuildContext context)?, Color? bgColor, TextStyle? titleStyle, TextStyle? descriptionStyle, Color? textColor, String? trailingAssetPath, void onTrailingPressed(BuildContext context)?})
-
const
Properties
- bgColor → Color?
-
bgColor Can be used to change background color
final
- body → Widget?
-
body can be used to show custom ui elements
specific to status card like progress, or any
other info.
final
- ctaButtonKey → Key?
-
ctaButtonKey takes the Key parameter of the cta button
final
- ctaText → String?
-
ctaText will be the label of the main cta button
final
- description → String?
-
title specifies the heading of the card.
final
- descriptionStyle → TextStyle?
-
descriptionStyle specifies the style of the description of the card.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onClose → void Function(BuildContext context)?
-
onClose adds a close icon on top right, when not null
final
- onTapCta → VoidCallback?
-
onTapCta will be used to provide callback to main cta
final
- onTrailingPressed → void Function(BuildContext context)?
-
onTrailingPressed adds a trailing icon on right, when not null
final
- prefixIcon → Widget?
-
prefixIcon defines the icon to show before
title, and description in a row
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textColor → Color?
-
textColor Can be used to change text color
final
- title → String?
-
title specifies the heading of the card.
final
- titleStyle → TextStyle?
-
titleStyle specifies the style of heading of the card.
final
- trailingAssetPath → String?
-
trailingAssetPath sets the icon data for trailing cta, when not null
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited